﻿using System.Windows;
using System.Windows.Input;
using Telerik.Windows.Controls;

namespace wpf_ChartView_1005308
{
    public static class ChartUtilities
    {
        public static readonly DependencyProperty PanCursorProperty = DependencyProperty.RegisterAttached(
            "PanCursor", 
            typeof(Cursor), 
            typeof(ChartUtilities),
            new PropertyMetadata(PanCursorChaged));
        
        public static Cursor GetPanCursor(DependencyObject obj)
        {
            return (Cursor)obj.GetValue(PanCursorProperty);
        }

        public static void SetPanCursor(DependencyObject obj, Cursor value)
        {
            obj.SetValue(PanCursorProperty, value);
        }

        private static void PanCursorChaged(DependencyObject target, DependencyPropertyChangedEventArgs args)
        {
            RadCartesianChart chart = (RadCartesianChart)target;
            chart.MouseLeftButtonDown -= Chart_MouseLeftButtonDown;
            chart.MouseLeftButtonUp -= Chart_MouseLeftButtonUp;

            Cursor cursor = (Cursor)args.NewValue;
            if (cursor != null)
            {
                chart.MouseLeftButtonDown += Chart_MouseLeftButtonDown;
                chart.MouseLeftButtonUp += Chart_MouseLeftButtonUp;
            }
        }

        static void Chart_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            RadCartesianChart chart = (RadCartesianChart)sender;
            Point pos = e.GetPosition(chart);
            
            if (IsInsidePlotArea(pos, chart))
            {
                chart.Cursor = GetPanCursor(chart);
            }
        }

        static void Chart_MouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            RadCartesianChart chart = (RadCartesianChart)sender;
            chart.Cursor = null;
        }

        private static bool IsInsidePlotArea(Point pos, RadCartesianChart chart)
        {
            return ((chart.PlotAreaClip.X + chart.PanOffset.X) <= pos.X) &&
                pos.X <= ((chart.PlotAreaClip.Right + chart.PanOffset.X)) && 
                ((chart.PlotAreaClip.Y + chart.PanOffset.Y) <= pos.Y) &&
                pos.Y <= ((chart.PlotAreaClip.Bottom + chart.PanOffset.Y));
        }
    }
}
